
2023 DEC 24

*   Implement initial FS_14_59_14_06 pending requests spinner.
*   Implement FS_02_25_41_81 `func_id_query_enum_items`.
*   Create one-liner `relay_demo.bash` (which starts & stops server in background).
*   Create initial GitHub CI.
